@@ -3,15 +3,14 @@ use Mojo::Base 'Mojolicious::Plugin';
 use Mojo::UserAgent;
 use Mojo::Headers;
 use Mojo::JSON;
-use Mojo::Util qw/quote/;
+use Mojo::Util qw/quote deprecated/;
 use Mojo::IOLoop;
 
 
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 
 my $WK_PATH = '/.well-known/host-meta';
-my $UA_NAME = __PACKAGE__ . ' v' . $VERSION;
 
 
 # Register plugin
@@ -33,14 +32,18 @@ sub register {
     $mojo->plugin("Util::$_") unless exists $helpers->{ lc $_ };
   };
 
-  # Set callbacks on registration
-  $mojo->callback(['hostmeta_fetch'] => $param);
-
   # Load XML if not already loaded
   unless (exists $helpers->{render_xrd}) {
     $mojo->plugin('XRD');
   };
 
+  # Set callbacks on registration
+  # !!! hostmeta_fetch is deprecated
+  $mojo->callback(
+    [qw/fetch_hostmeta hostmeta_fetch/],
+    $param
+  );
+
   # Get seconds to expiration
   my $seconds = (60 * 60 * 24 * 10);
   if ($param->{expires} && $param->{expires} =~ /^\d+$/) {
@@ -55,7 +58,7 @@ sub register {
   $mojo->hook(
     prepare_hostmeta =>
       sub {
-	my ($c, $xrd_ref) = @_;
+	my ($c, $hostmeta) = @_;
 	my $host = $c->req->url->to_abs->host;
 
 	# Add host-information to host-meta
@@ -146,9 +149,19 @@ sub _fetch_hostmeta {
 
   # Callback for caching
   my ($xrd, $headers) = $c->callback(
-    hostmeta_fetch => $host
+    fetch_hostmeta => $host
   );
 
+  # !!! Deprecated in 0.5
+  unless ($xrd) {
+    ($xrd, $headers) = $c->callback(
+      hostmeta_fetch => $host
+    );
+    if ($xrd) {
+      deprecated 'hostmeta_fetch is DEPRECATED in favor of fetch_hostmeta';
+    };
+  };
+
   # HostMeta document was cached
   if ($xrd) {
 
@@ -298,7 +311,7 @@ Mojolicious::Plugin::HostMeta - Serve and Retrieve Host-Meta documents
 =head1 SYNOPSIS
 
   # Mojolicious
-  $self->plugin('HostMeta');
+  $app->plugin('HostMeta');
 
   # Mojolicious::Lite
   plugin 'HostMeta';
@@ -306,10 +319,10 @@ Mojolicious::Plugin::HostMeta - Serve and Retrieve Host-Meta documents
   # Serves XRD or JRD from /.well-known/host-meta
 
   # Blocking requests
-  print $self->hostmeta('gmail.com')->link('lrrd');
+  print $c->hostmeta('gmail.com')->link('lrrd');
 
   # Non-blocking requests
-  $self->hostmeta('gmail.com' => sub {
+  $c->hostmeta('gmail.com' => sub {
     print shift->link('lrrd');
   });
 
@@ -320,6 +333,7 @@ L<Mojolicious::Plugin::HostMeta> is a Mojolicious plugin to serve and
 request "well-known" L<Host-Meta|https://tools.ietf.org/html/rfc6415>
 documents.
 
+B<This module is an early release! There may be significant changes in the future.>
 
 =head1 METHODS
 
@@ -346,14 +360,14 @@ as part of the configuration file with the key C<HostMeta>.
 =head2 C<hostmeta>
 
   # In Controller:
-  my $xrd = $self->hostmeta;
-  $xrd = $self->hostmeta('gmail.com');
-  $xrd = $self->hostmeta('sojolicio.us' => ['hub']);
-  $xrd = $self->hostmeta('sojolicio.us', { 'X-MyHeader' => 'Fun' } => ['hub']);
-  $xrd = $self->hostmeta('gmail.com', -secure);
+  my $xrd = $c->hostmeta;
+  $xrd = $c->hostmeta('gmail.com');
+  $xrd = $c->hostmeta('sojolicio.us' => ['hub']);
+  $xrd = $c->hostmeta('sojolicio.us', { 'X-MyHeader' => 'Fun' } => ['hub']);
+  $xrd = $c->hostmeta('gmail.com', -secure);
 
   # Non blocking
-  $self->hostmeta('gmail.com' => ['hub'] => sub {
+  $c->hostmeta('gmail.com' => ['hub'] => sub {
     my $xrd = shift;
     # ...
   }, -secure);
@@ -381,11 +395,11 @@ last argument before the optional C<-secure> flag to the method.
 
 =head1 CALLBACKS
 
-=head2 hostmeta_fetch
+=head2 fetch_hostmeta
 
   # Establish a callback
   $mojo->callback(
-    hostmeta_fetch => sub {
+    fetch_hostmeta => sub {
       my ($c, $host) = @_;
 
       my $doc = $c->chi->get("hostmeta-$host");
@@ -413,6 +427,8 @@ helper or on registration.
 
 This can be used for caching.
 
+The callback C<hostmeta_fetch> is deprecated.
+
 
 =head1 HOOKS
 
@@ -503,6 +519,8 @@ L<Mojolicious::Plugin::XRD>.
 
   https://github.com/Akron/Mojolicious-Plugin-HostMeta
 
+This plugin is part of the L<Sojolicious|http://sojolicio.us> project.
+
 
 =head1 COPYRIGHT AND LICENSE
 
